@@ -554,10 +554,10 @@ class DataTransform(forms.ModelForm):
     def __init__(self, *args, **kwargs):
         super(DataTransform, self).__init__(*args, **kwargs)
         try:
-            if hasattr(self.instance, 'get_children') and self.instance.get_children() > 0:
+            if hasattr(self.instance, 'get_children') and self.instance.get_children().count() > 0:
                 dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
                                                                      fk_name='parent', form=DataTransform,
-                                                                     extra=self.instance.get_children() + 1
+                                                                     extra=self.instance.get_children().count() + 1
                                                                      )
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
                     instance=self.instance,
@@ -568,7 +568,6 @@ class DataTransform(forms.ModelForm):
         except Exception:
             print('excpt')
 
-        self.instance.get_children().count() + 1
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
